@@ -12,8 +12,9 @@
 const work_dir = process.cwd();
 
 module.exports = function (app, db, nylon_path) {
-    app.set('views', work_dir + '/app/views');
-    app.set('views', nylon_path + '/lib/public/views');
+
+   // app.set('views', nylon_path + '/lib/app/views');
+    app.set('views',[ nylon_path + '/lib/app/views', work_dir + '/app/views']);
     app.set('view engine', 'jade');
-   
+
 }
\ No newline at end of file
